==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridEmptyTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridEmptyTemplateContextDescription } from "./WebGridEmptyTemplateContextDescription";
/**
 * @hidden
 */
var WebGridEmptyTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridEmptyTemplateContextDescriptionMetadata, _super);
    function WebGridEmptyTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridEmptyTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridEmptyTemplateContextDescriptionMetadata.a == null) {
            WebGridEmptyTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridEmptyTemplateContextDescriptionMetadata.c(WebGridEmptyTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebGridEmptyTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridEmptyTemplateContextDescriptionMetadata.a);
    };
    WebGridEmptyTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridEmptyTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebGridEmptyTemplateContextDescriptionMetadata.d = function (a) {
        WebGridEmptyTemplateContextDescriptionMetadata.b(a);
        a.aa("WebGridEmptyTemplateContext", function () { return new WebGridEmptyTemplateContextDescription(); });
        a.z("WebGridEmptyTemplateContext", WebGridEmptyTemplateContextDescriptionMetadata.a);
    };
    WebGridEmptyTemplateContextDescriptionMetadata.$t = markType(WebGridEmptyTemplateContextDescriptionMetadata, 'WebGridEmptyTemplateContextDescriptionMetadata');
    WebGridEmptyTemplateContextDescriptionMetadata.a = null;
    return WebGridEmptyTemplateContextDescriptionMetadata;
}(Base));
export { WebGridEmptyTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridEmptyTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridEmptyTemplateContextDescription } from "./WebGridEmptyTemplateContextDescription";
/**
 * @hidden
 */
var WebGridEmptyTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridEmptyTemplateContextDescriptionMetadata, _super);
    function WebGridEmptyTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridEmptyTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridEmptyTemplateContextDescriptionMetadata.a == null) {
            WebGridEmptyTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridEmptyTemplateContextDescriptionMetadata.c(WebGridEmptyTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridEmptyTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridEmptyTemplateContextDescriptionMetadata.a);
    };
    WebGridEmptyTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridEmptyTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebGridEmptyTemplateContextDescriptionMetadata.d = function (a) {
        WebGridEmptyTemplateContextDescriptionMetadata.b(a);
        a.ac("WebGridEmptyTemplateContext", function () { return new WebGridEmptyTemplateContextDescription(); });
        a.ab("WebGridEmptyTemplateContext", WebGridEmptyTemplateContextDescriptionMetadata.a);
    };
    WebGridEmptyTemplateContextDescriptionMetadata.$t = markType(WebGridEmptyTemplateContextDescriptionMetadata, 'WebGridEmptyTemplateContextDescriptionMetadata');
    WebGridEmptyTemplateContextDescriptionMetadata.a = null;
    return WebGridEmptyTemplateContextDescriptionMetadata;
}(Base));
export { WebGridEmptyTemplateContextDescriptionMetadata };
